"use client"
import React, { useState, useEffect } from 'react'
import Sidebar from '@/components/dashboard/Sidebar'
import Form from './Form'
import axios from '@/services/APIservices'

const Page = () => {
  const [userData, setUserData] = useState(null)
  const [editUserData, setEditUserData] = useState({
    name: '',
    email: '',
    mobile_number: '',
    profile_photo: '',
  }) // Initialize with default empty values
  const [loading, setLoading] = useState(true)
  const [error, setError] = useState(null)

  useEffect(() => {
    const storedUserData = localStorage.getItem('userData')
    if (storedUserData) {
      setUserData(JSON.parse(storedUserData))
    }
  }, [])

  const userId = userData?.user_id || null

  // Fetch data from API
  const fetchApiData = async () => {
    if (!userId) {
      setLoading(false)
      return
    }

    try {
      const response = await axios.get(`/api/dashboard/${userId}`)
      if (response.data.success) {
        setEditUserData(response.data.data)
        setError(null)
      } else {
        throw new Error("Failed to fetch user data")
      }
    } catch (err) {
      console.error("Error fetching user data:", err)
      setError("Failed to load user details")
    } finally {
      setLoading(false)
    }
  }

  useEffect(() => {
    fetchApiData()
    // Removed the polling setup
  }, [userId])

  if (loading) {
    return (
      <div className='bg-[#ededed] h-screen flex justify-center items-center'>
        <div className="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-brand"></div>
      </div>
    )
  }

  if (error) {
    return (
      <div className='bg-[#ededed] h-screen flex justify-center items-center text-red-500'>
        {error}
      </div>
    )
  }

  return ( 
    <div className='bg-[#ededed] h-screen flex flex-col justify-center px-16'>
      <div className='flex gap-16'>
        <Sidebar path={"/account-settings"} 
                 userId={userId} 
                 userImage={editUserData ? editUserData.profile_photo : null}  
        />
        <div className='w-2/3'>
          <Form userId={userId} editUserData={editUserData} setEditUserData={setEditUserData} />
        </div>
      </div>
    </div>
  )
}

export default Page 
